@@ -125,7 +125,7 @@ int
 is_valid_ipv4_addr(const char * const ip_str, const int len)
 {
     const char         *ndx     = ip_str;
-    char         tmp_ip_str[MAX_IPV4_STR_LEN + 1]={0};
+    char         tmp_ip_str[MAX_IPV4_STR_LEN + 1] = {0};
     int                 dot_ctr = 0, char_ctr = 0;
     int                 res     = 1;
 #if HAVE_SYS_SOCKET_H
@@ -138,10 +138,9 @@ is_valid_ipv4_addr(const char * const ip_str, const int len)
     if((len > MAX_IPV4_STR_LEN) || (len < MIN_IPV4_STR_LEN))
         return 0;
 
-
     while(char_ctr < len)
     {
-        /* If we've hit a null within the given length, then not valid regardless*/
+        /* If we've hit a null within the given length, then not valid regardless */
         if(*ndx == '\0')
             return 0;
 
@@ -157,8 +156,6 @@ is_valid_ipv4_addr(const char * const ip_str, const int len)
         ndx++;
     }
 
-
-
     if((res == 1) && (dot_ctr != 3))
         res = 0;
 
@@ -565,6 +562,24 @@ strtol_wrapper(const char * const str, const int min,
     return val;
 }
 
+/* Chop whitespace off the end of a string (must be NULL-terminated)
+*/
+void
+chop_whitespace(char *str)
+{
+    int i;
+    for (i=strlen(str)-1; i > 0; i--)
+    {
+        if (! isspace(str[i]))
+        {
+            if (i < strlen(str)-1)
+                str[i+1] = 0x0;
+            break;
+        }
+    }
+    return;
+}
+
 /* zero out a buffer before free()
 */
 int zero_free(char *buf, int len)
