@@ -1,13 +1,12 @@
-/*
- *****************************************************************************
+/**
+ * \file server/fw_util_ipfw.c
  *
- * File:    fw_util_ipfw.c
- *
- * Author:  Damien S. Stuart
- *
- * Purpose: Fwknop routines for managing ipfw firewall rules.
- *
- * Copyright 2010-2013 Damien Stuart (dstuart@dstuart.org)
+ * \brief Fwknop routines for managing ipfw firewall rules.
+ */
+
+/*  Fwknop is developed primarily by the people listed in the file 'AUTHORS'.
+ *  Copyright (C) 2009-2015 fwknop developers and contributors. For a full
+ *  list of contributors, see the file 'CREDITS'.
  *
  *  License (GNU General Public License):
  *
@@ -65,6 +64,8 @@ zero_cmd_buffers(void)
     memset(cmd_out, 0x0, STANDARD_CMD_OUT_BUFSIZE);
 }
 
+static int pid_status = 0;
+
 static int
 ipfw_set_exists(const fko_srv_options_t *opts,
     const char *fw_command, const unsigned short set_num)
@@ -78,7 +79,8 @@ ipfw_set_exists(const fko_srv_options_t *opts,
         set_num
     );
 
-    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE, 0);
+    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE,
+            WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
     log_msg(LOG_DEBUG, "ipfw_set_exists() CMD: '%s' (res: %d)",
         cmd_buf, res);
@@ -113,7 +115,8 @@ fw_dump_rules(const fko_srv_options_t * const opts)
             opts->fw_config->fw_command
         );
 
-        res = system(cmd_buf);
+        res = run_extcmd(cmd_buf, NULL, 0, NO_STDERR,
+                        NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_dump_rules() CMD: '%s' (res: %d)",
             cmd_buf, res);
@@ -140,7 +143,8 @@ fw_dump_rules(const fko_srv_options_t * const opts)
         );
 
         printf("\nActive Rules:\n");
-        res = system(cmd_buf);
+        res = run_extcmd(cmd_buf, NULL, 0, NO_STDERR,
+                    NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_dump_rules() CMD: '%s' (res: %d)",
             cmd_buf, res);
@@ -160,7 +164,8 @@ fw_dump_rules(const fko_srv_options_t * const opts)
         );
 
         printf("\nExpired Rules:\n");
-        res = system(cmd_buf);
+        res = run_extcmd(cmd_buf, NULL, 0, NO_STDERR,
+                    NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_dump_rules() CMD: '%s' (res: %d)",
             cmd_buf, res);
@@ -232,6 +237,11 @@ fw_config_init(fko_srv_options_t * const opts)
                 RCHK_MAX_IPFW_PURGE_INTERVAL);
         return 0;
     }
+    
+    if(strncasecmp(opts->config[CONF_ENABLE_DESTINATION_RULE], "Y", 1)==0)
+    {
+        fwc.use_destination = 1;
+    }
 
     /* Let us find it via our opts struct as well.
     */
@@ -280,7 +290,8 @@ fw_initialize(const fko_srv_options_t * const opts)
             fwc.active_set_num
         );
 
-        res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE, 0);
+        res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE,
+                    WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_initialize() CMD: '%s' (res: %d, err: %s)",
             cmd_buf, res, err_buf);
@@ -310,7 +321,8 @@ fw_initialize(const fko_srv_options_t * const opts)
             fwc.expire_set_num
         );
 
-        res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE, 0);
+        res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE,
+                    WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_initialize() CMD: '%s' (res: %d, err: %s)",
             cmd_buf, res, err_buf);
@@ -332,7 +344,8 @@ fw_initialize(const fko_srv_options_t * const opts)
         fwc.expire_set_num
     );
 
-    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE, 0);
+    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE,
+                WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
     log_msg(LOG_DEBUG, "fw_initialize() CMD: '%s' (res: %d)",
         cmd_buf, res);
@@ -413,7 +426,8 @@ fw_cleanup(const fko_srv_options_t * const opts)
             fwc.active_set_num
         );
 
-        res = system(cmd_buf);
+        res = run_extcmd(cmd_buf, NULL, 0, NO_STDERR,
+                    NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "fw_cleanup() CMD: '%s' (res: %d)",
             cmd_buf, res);
@@ -499,7 +513,7 @@ process_spa_request(const fko_srv_options_t * const opts,
         */
         rule_num = get_next_rule_num();
 
-        /* If rule_num comes back as 0, we aready have the maximum number
+        /* If rule_num comes back as 0, we already have the maximum number
          * of active rules allowed so we reject and bail here.
         */
         if(rule_num == 0)
@@ -522,11 +536,13 @@ process_spa_request(const fko_srv_options_t * const opts,
                 fwc.active_set_num,
                 ple->proto,
                 spadat->use_src_ip,
+                (fwc.use_destination ? spadat->pkt_destination_ip : IPFW_ANY_IP),
                 ple->port,
                 exp_ts
             );
 
-            res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE, 0);
+            res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE,
+                            WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
             log_msg(LOG_DEBUG, "process_spa_request() CMD: '%s' (res: %d, err: %s)",
                 cmd_buf, res, err_buf);
@@ -584,7 +600,8 @@ process_spa_request(const fko_srv_options_t * const opts,
  * firewall rules.
 */
 void
-check_firewall_rules(const fko_srv_options_t * const opts)
+check_firewall_rules(const fko_srv_options_t * const opts,
+        const int chk_rm_all)
 {
     char            exp_str[12]     = {0};
     char            rule_num_str[6] = {0};
@@ -620,7 +637,9 @@ check_firewall_rules(const fko_srv_options_t * const opts)
         fwc.active_set_num
     );
 
-    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE, 0);
+    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE,
+                WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
+    chop_newline(cmd_out);
 
     log_msg(LOG_DEBUG, "check_firewall_rules() CMD: '%s' (res: %d)",
         cmd_buf, res);
@@ -663,6 +682,15 @@ check_firewall_rules(const fko_srv_options_t * const opts)
         tmp_mark = ndx;
 
         strlcpy(exp_str, ndx, sizeof(exp_str));
+        chop_spaces(exp_str);
+        if(!is_digits(exp_str))
+        {
+            /* go to the next rule if it exists
+            */
+            ndx = strstr(tmp_mark, EXPIRE_COMMENT_PREFIX);
+            continue;
+        }
+
         rule_exp = (time_t)atoll(exp_str);
 
         if(rule_exp <= now)
@@ -726,7 +754,8 @@ check_firewall_rules(const fko_srv_options_t * const opts)
                     fwc.expire_set_num
                 );
 
-                res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE, 0);
+                res = run_extcmd(cmd_buf, err_buf, CMD_BUFSIZE,
+                            WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
                 log_msg(LOG_DEBUG, "check_firewall_rules() CMD: '%s' (res: %d, err: %s)",
                     cmd_buf, res, err_buf);
@@ -794,7 +823,8 @@ ipfw_purge_expired_rules(const fko_srv_options_t *opts)
         fwc.expire_set_num
     );
 
-    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE, 0);
+    res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE,
+            WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
     log_msg(LOG_DEBUG, "ipfw_purge_expired_rules() CMD: '%s' (res: %d)",
         cmd_buf, res);
@@ -901,7 +931,8 @@ ipfw_purge_expired_rules(const fko_srv_options_t *opts)
             curr_rule
         );
 
-        res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE, 0);
+        res = run_extcmd(cmd_buf, cmd_out, STANDARD_CMD_OUT_BUFSIZE,
+                    WANT_STDERR, NO_TIMEOUT, &pid_status, opts);
 
         log_msg(LOG_DEBUG, "ipfw_purge_expired_rules() CMD: '%s' (res: %d)",
             cmd_buf, res);
