@@ -69,7 +69,7 @@ static void enable_fault_injections(fko_srv_options_t * const opts);
 #endif
 
 #if AFL_FUZZING
-#define AFL_MAX_PKT_SIZE  1024
+#define AFL_MAX_PKT_SIZE  MAX_SPA_ENCODED_MSG_SIZE
 #define AFL_DUMP_CTX_SIZE 4096
 #endif
 
@@ -376,10 +376,11 @@ static void afl_enc_pkt_from_file(fko_srv_options_t *opts)
         {
             enc_spa_pkt[enc_msg_len] = rc;
             enc_msg_len++;
-            if(enc_msg_len == AFL_MAX_PKT_SIZE-1)
+            if(enc_msg_len == AFL_MAX_PKT_SIZE-2)
                 break;
         }
         fclose(fp);
+        enc_msg_len++;
 
         fko_new(&decrypt_ctx);
 
@@ -677,17 +678,24 @@ static int stop_fwknopd(fko_srv_options_t * const opts)
                 }
                 sleep(1);
             }
-            if(is_err != 0)
+
+            /* if we make it here at all, then we were unsuccessful with the
+             * above attempt to kill the process with SIGTERM
+            */
+            res    = kill(old_pid, SIGKILL);
+            is_err = kill(old_pid, 0);
+            if(res == 0 && is_err != 0)
             {
-                fprintf(stdout, "Killed fwknopd (pid=%i) via SIGTERM\n",
+                fprintf(stdout,
+                        "Killed fwknopd (pid=%i) via SIGKILL\n",
                         old_pid);
                 return EXIT_SUCCESS;
             }
             else
             {
-                res    = kill(old_pid, SIGKILL);
+                sleep(1);
                 is_err = kill(old_pid, 0);
-                if(res == 0 && is_err != 0)
+                if(is_err != 0)
                 {
                     fprintf(stdout,
                             "Killed fwknopd (pid=%i) via SIGKILL\n",
@@ -696,20 +704,8 @@ static int stop_fwknopd(fko_srv_options_t * const opts)
                 }
                 else
                 {
-                    sleep(1);
-                    is_err = kill(old_pid, 0);
-                    if(is_err != 0)
-                    {
-                        fprintf(stdout,
-                                "Killed fwknopd (pid=%i) via SIGKILL\n",
-                                old_pid);
-                        return EXIT_SUCCESS;
-                    }
-                    else
-                    {
-                        perror("Unable to kill fwknop: ");
-                        return EXIT_FAILURE;
-                    }
+                    perror("Unable to kill fwknop: ");
+                    return EXIT_FAILURE;
                 }
             }
         }
@@ -1020,12 +1016,6 @@ get_running_pid(const fko_srv_options_t *opts)
     pid_t   rpid            = 0;
 
 
-    if(verify_file_perms_ownership(opts->config[CONF_FWKNOP_PID_FILE]) != 1)
-    {
-        fprintf(stderr, "verify_file_perms_ownership() error\n");
-        return(rpid);
-    }
-
     op_fd = open(opts->config[CONF_FWKNOP_PID_FILE], O_RDONLY);
 
     if(op_fd == -1)
@@ -1035,13 +1025,20 @@ get_running_pid(const fko_srv_options_t *opts)
         return(rpid);
     }
 
+    if(verify_file_perms_ownership(opts->config[CONF_FWKNOP_PID_FILE], op_fd) != 1)
+    {
+        fprintf(stderr, "verify_file_perms_ownership() error\n");
+        close(op_fd);
+        return(rpid);
+    }
+
     bytes_read = read(op_fd, buf, PID_BUFLEN);
     if (bytes_read > 0)
     {
         buf[PID_BUFLEN-1] = '\0';
         /* max pid value is configurable on Linux
         */
-        rpid = (pid_t) strtol_wrapper(buf, 0, (2 << 30),
+        rpid = (pid_t) strtol_wrapper(buf, 0, (2 << 22),
                 NO_EXIT_UPON_ERR, &is_err);
         if(is_err != FKO_SUCCESS)
             rpid = 0;
