@@ -96,14 +96,21 @@ preprocess_spa_data(const fko_srv_options_t *opts, spa_pkt_info_t *spa_pkt, spa_
      * assume it is a SPA over HTTP request.
     */
     if(strncasecmp(opts->config[CONF_ENABLE_SPA_OVER_HTTP], "Y", 1) == 0
-      && strncasecmp(ndx, "GET /", 5) == 0
-      && strstr(ndx, "User-Agent: Fwknop") != NULL)
+      && strncasecmp(ndx, "GET /", 5) == 0)
     {
         /* This looks like an HTTP request, so let's see if we are
          * configured to accept such request and if so, find the SPA
          * data.
         */
 
+        /* First see if we require the User-Agent to start with 'Fwknop'
+        */
+        if(strncasecmp(opts->config[CONF_ALLOW_ANY_USER_AGENT], "N", 1) == 0
+          && strstr(ndx, "User-Agent: Fwknop") == NULL)
+        {
+            return(SPA_MSG_BAD_DATA);
+        }
+
         /* Process X-Forwarded-For header */
 
         xff = strcasestr(ndx, "X-Forwarded-For: ");
@@ -554,8 +561,18 @@ check_mode_ctx(spa_data_t *spadat, fko_ctx_t *ctx, int attempted_decrypt,
     */
     if(res != FKO_SUCCESS)
     {
-        log_msg(LOG_WARNING, "[%s] (stanza #%d) Error creating fko context: %s",
-            spadat->pkt_source_ip, stanza_num, fko_errstr(res));
+        if(res == FKO_ERROR_INVALID_DATA_HMAC_COMPAREFAIL)
+        {
+            log_msg(LOG_DEBUG, "[%s] (stanza #%d) Error creating fko context: %s",
+                spadat->pkt_source_ip, stanza_num, fko_errstr(res));
+            log_msg(LOG_INFO, "(stanza #%d) Non-corresponding HMAC for this stanza",
+                stanza_num);
+        }
+        else
+        {
+            log_msg(LOG_WARNING, "[%s] (stanza #%d) Error creating fko context: %s",
+                spadat->pkt_source_ip, stanza_num, fko_errstr(res));
+        }
 
         if(IS_GPG_ERROR(res))
             log_msg(LOG_WARNING, "[%s] (stanza #%d) - GPG ERROR: %s",
