@@ -32,6 +32,10 @@ def main():
     print "Version:", fko.version()
     print "Timestamp:", fko.timestamp()
     print "Username:", fko.username()
+    print "Encryption Type (value):", fko.encryption_type()
+    print "Encryption Type (string):", fko.encryption_type_str()
+    print "Encryption Mode (value):", fko.encryption_mode()
+    print "Encryption Mode (string):", fko.encryption_mode_str()
     print "Digest Type (value):", fko.digest_type()
     print "Digest Type (string):", fko.digest_type_str()
     print "Digest:", fko.spa_digest()
