@@ -161,6 +161,20 @@ spa_encoded_msg_fuzzing(void)
             }
         }
 
+        /* decode again for good measure */
+        res = fko_decode_spa_data(decode_ctx);
+        if (require_success) {
+            if (res != FKO_SUCCESS) {
+                printf("[-] pkt_id: %d, expected decode success but: fko_decode_spa_data(): %s\n",
+                        pkt_id, fko_errstr(res));
+            }
+        } else {
+            if (res == FKO_SUCCESS) {
+                printf("[-] pkt_id: %d, expected decode failure but: fko_decode_spa_data(): %s\n",
+                        pkt_id, fko_errstr(res));
+            }
+        }
+
         if (0) {
                 fko_destroy(decode_ctx);
                 decode_ctx = NULL;
@@ -397,6 +411,13 @@ test_loop(int new_ctx_flag, int destroy_ctx_flag)
             FKO_LAST_MSG_TYPE+F_INT, FKO_ACCESS_MSG,
             NO_DIGEST, new_ctx_flag, destroy_ctx_flag);
 
+    /* exercise error path since this offset range will hit negative
+     * values in fko_set_timestamp()
+    */
+    spa_func_int(&ctx, "fko_set_timestamp",
+            &fko_set_timestamp, -(time(NULL)+1000), -(time(NULL)+200), 10,
+            new_ctx_flag, destroy_ctx_flag);
+
     spa_func_int(&ctx, "fko_set_timestamp",
             &fko_set_timestamp, -F_INT, F_INT, 10,
             new_ctx_flag, destroy_ctx_flag);
@@ -419,6 +440,18 @@ test_loop(int new_ctx_flag, int destroy_ctx_flag)
         ctx_update(&ctx, new_ctx_flag, destroy_ctx_flag, DO_PRINT);
     }
 
+    for (i=0; i<FCN_CALLS; i++) {
+        printf("fko_set_username(|bogususer): %s\n",
+                fko_errstr(fko_set_username(ctx, "|bogususer")));
+        ctx_update(&ctx, new_ctx_flag, destroy_ctx_flag, DO_PRINT);
+    }
+
+    for (i=0; i<FCN_CALLS; i++) {
+        printf("fko_set_username(bogus|user): %s\n",
+                fko_errstr(fko_set_username(ctx, "bogus|user")));
+        ctx_update(&ctx, new_ctx_flag, destroy_ctx_flag, DO_PRINT);
+    }
+
     spa_func_getset_short(&ctx, "fko_set_spa_encryption_type",
             &fko_set_spa_encryption_type, "fko_get_spa_encryption_type",
             &fko_get_spa_encryption_type, FKO_ENCRYPTION_INVALID_DATA-F_INT,
@@ -458,8 +491,8 @@ test_loop(int new_ctx_flag, int destroy_ctx_flag)
             DO_DIGEST, new_ctx_flag, destroy_ctx_flag);
 
     spa_func_getset_short(&ctx, "fko_set_raw_spa_digest_type",
-            &fko_set_spa_digest_type, "fko_get_raw_spa_digest_type",
-            &fko_get_spa_digest_type, FKO_DIGEST_INVALID_DATA-F_INT,
+            &fko_set_raw_spa_digest_type, "fko_get_raw_spa_digest_type",
+            &fko_get_raw_spa_digest_type, FKO_DIGEST_INVALID_DATA-F_INT,
             FKO_LAST_DIGEST_TYPE+F_INT, FKO_DEFAULT_DIGEST,
             RAW_DIGEST, new_ctx_flag, destroy_ctx_flag);
 
@@ -761,6 +794,7 @@ display_ctx(fko_ctx_t ctx)
     time_t      timestamp       = 0;
     short       msg_type        = -1;
     short       digest_type     = -1;
+    short       raw_digest_type = -1;
     short       hmac_type       = -1;
     int         encryption_mode = -1;
     int         client_timeout  = -1;
@@ -788,6 +822,8 @@ display_ctx(fko_ctx_t ctx)
     fko_get_spa_client_timeout(ctx, &client_timeout);
     fko_get_spa_digest_type(ctx, NULL);
     fko_get_spa_digest_type(ctx, &digest_type);
+    fko_get_raw_spa_digest_type(ctx, NULL);
+    fko_get_raw_spa_digest_type(ctx, &raw_digest_type);
     fko_get_spa_hmac_type(ctx, NULL);
     fko_get_spa_hmac_type(ctx, &hmac_type);
     fko_get_spa_encryption_mode(ctx, NULL);
