@@ -13,6 +13,33 @@
         'fw_rule_removed' => $NEW_RULE_REMOVED,
         'key_file' => $cf{'rc_hmac_b64_key'},
     },
+    {
+        'category' => 'GPG (no pw) HMAC',
+        'subcategory' => 'client+server',
+        'detail'   => 'complete cycle same key signer',
+        'function' => \&spa_cycle,
+        'cmdline'  => "$default_client_gpg_args_same_key_signer "
+            . "--gpg-home-dir $gpg_client_home_dir_no_pw "
+            . "--rc-file $cf{'rc_hmac_b64_key'}",
+        'fwknopd_cmdline' => "LD_LIBRARY_PATH=$lib_dir " .
+            "$valgrind_str $fwknopdCmd -c $cf{'def'} " .
+            "-a $cf{'gpg_no_pw_hmac_clientdir_access'} $intf_str " .
+            "-d $default_digest_file -p $default_pid_file",
+        'fw_rule_created' => $NEW_RULE_REQUIRED,
+        'fw_rule_removed' => $NEW_RULE_REMOVED,
+        'key_file' => $cf{'rc_hmac_b64_key'},
+    },
+    {
+        'category' => 'GPG (no pw) HMAC',
+        'subcategory' => 'client',
+        'detail'   => 'same signing key --test',
+        'function' => \&generic_exec,
+        'cmdline'  => "$default_client_gpg_args_same_key_signer "
+            . "--gpg-home-dir $gpg_client_home_dir_no_pw "
+            . "--rc-file $cf{'rc_hmac_b64_key'} --test",
+        'key_file' => $cf{'rc_hmac_b64_key'},
+    },
+
     {
         'category' => 'GPG (no pw) HMAC',
         'subcategory' => 'client+server',
